# mydf

An extended version for [`dfply`](https://github.com/kieferk/dfply).

### Extended functions:
- [Summarization](#)
  - [`r()`](#)
- [Reshape](#)
  - [`expand()`](#)
- [Embedded column functions](#)
  - [`Len()`](#)
  - [`to_df()`](#)
  - [`to_list()`](#)
  - [`where()`](#)
  - [`case_when()`](#)
  - [`Join()`](#)
